@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,7 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
 
 #include <vector>
 #include <list>
@@ -116,9 +116,9 @@ using namespace sw::types;
 using namespace sw::mark;
 using namespace nsFieldFlags;
 
-
 static String lcl_getFieldCode( const IFieldmark* pFieldmark ) {
-    ASSERT(pFieldmark!=NULL, "where is my fieldmark???");
+    OSL_ENSURE(pFieldmark!=NULL, "where is my fieldmark???");
+
     if ( pFieldmark->GetFieldname( ).equalsAscii( ODF_FORMTEXT ) ) {
         return String::CreateFromAscii(" FORMTEXT ");
     } else if ( pFieldmark->GetFieldname( ).equalsAscii( ODF_FORMDROPDOWN ) ) {
@@ -137,7 +137,7 @@ static String lcl_getFieldCode( const IFieldmark* pFieldmark ) {
 }
 
 ww::eField lcl_getFieldId( const IFieldmark* pFieldmark ) {
-    ASSERT(pFieldmark!=NULL, "where is my fieldmark???");
+    OSL_ENSURE(pFieldmark!=NULL, "where is my fieldmark???");
     if ( pFieldmark->GetFieldname( ).equalsAscii( ODF_FORMTEXT ) ) {
         return ww::eFORMTEXT;
     } else if ( pFieldmark->GetFieldname( ).equalsAscii( ODF_FORMDROPDOWN ) ) {
@@ -178,15 +178,15 @@ public:
     }
 };
 
-void SwAttrIter::IterToCurrent()
+void SwWW8AttrIter::IterToCurrent()
 {
-    ASSERT(maCharRuns.begin() != maCharRuns.end(), "Impossible");
+    OSL_ENSURE(maCharRuns.begin() != maCharRuns.end(), "Impossible");
     mnScript = maCharRunIter->mnScript;
     meChrSet = maCharRunIter->meCharSet;
     mbCharIsRTL = maCharRunIter->mbRTL;
 }
 
-SwAttrIter::SwAttrIter(MSWordExportBase& rWr, const SwTxtNode& rTxtNd) :
+SwWW8AttrIter::SwWW8AttrIter(MSWordExportBase& rWr, const SwTxtNode& rTxtNd) :
     MSWordAttrIter(rWr),
     rNd(rTxtNd),
     maCharRuns(GetPseudoCharRuns(rTxtNd, 0, !rWr.HackIsWW8OrHigher())),
@@ -253,7 +253,7 @@ xub_StrLen lcl_getMinPos( xub_StrLen pos1, xub_StrLen pos2 )
     return min;
 }
 
-xub_StrLen SwAttrIter::SearchNext( xub_StrLen nStartPos )
+xub_StrLen SwWW8AttrIter::SearchNext( xub_StrLen nStartPos )
 {
     xub_StrLen nPos;
     xub_StrLen nMinPos = STRING_MAXLEN;
@@ -393,7 +393,7 @@ bool lcl_isFontsizeItem( const SfxPoolItem& rItem )
             rItem.Which( ) == RES_CHRATR_CTL_FONTSIZE );
 }
 
-void SwAttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
+void SwWW8AttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
 {
     m_rExport.AttrOutput().RTLAndCJKState( IsCharRTL(), GetScript() );
 
@@ -477,7 +477,7 @@ void SwAttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
         ClearOverridesFromSet( *pCharFmtItem, aExportSet );
 
     sw::PoolItems aExportItems;
-    GetPoolItems( aExportSet, aExportItems );
+    GetPoolItems( aExportSet, aExportItems, false );
 
     sw::cPoolItemIter aEnd = aRangeItems.end();
     for ( sw::cPoolItemIter aI = aRangeItems.begin(); aI != aEnd; ++aI )
@@ -499,7 +499,7 @@ void SwAttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
         m_rExport.pOutFmtNode = pOldMod;
     }
 
-    ASSERT( pFont, "must be *some* font associated with this txtnode" );
+    OSL_ENSURE( pFont, "must be *some* font associated with this txtnode" );
     if ( pFont )
     {
         SvxFontItem aFont( *pFont );
@@ -522,7 +522,7 @@ void SwAttrIter::OutAttr( xub_StrLen nSwPos, bool bRuby )
     }
 }
 
-void SwAttrIter::OutFlys(xub_StrLen nSwPos)
+void SwWW8AttrIter::OutFlys(xub_StrLen nSwPos)
 {
     /*
      #i2916#
@@ -544,7 +544,7 @@ void SwAttrIter::OutFlys(xub_StrLen nSwPos)
     }
 }
 
-bool SwAttrIter::IsTxtAttr( xub_StrLen nSwPos )
+bool SwWW8AttrIter::IsTxtAttr( xub_StrLen nSwPos )
 {
     // search for attrs with CH_TXTATR
     if (const SwpHints* pTxtAttrs = rNd.GetpSwpHints())
@@ -560,7 +560,7 @@ bool SwAttrIter::IsTxtAttr( xub_StrLen nSwPos )
     return false;
 }
 
-bool SwAttrIter::IsDropCap( int nSwPos )
+bool SwWW8AttrIter::IsDropCap( int nSwPos )
 {
     // see if the current position falls on a DropCap
     int nDropChars = mrSwFmtDrop.GetChars();
@@ -579,7 +579,7 @@ bool SwAttrIter::IsDropCap( int nSwPos )
     return false;
 }
 
-bool SwAttrIter::RequiresImplicitBookmark()
+bool SwWW8AttrIter::RequiresImplicitBookmark()
 {
     SwImplBookmarksIter bkmkIterEnd = m_rExport.maImplicitBookmarks.end();
     for ( SwImplBookmarksIter aIter = m_rExport.maImplicitBookmarks.begin(); aIter != bkmkIterEnd; ++aIter )
@@ -598,7 +598,7 @@ bool SwAttrIter::RequiresImplicitBookmark()
 // Attribut-Anfangposition fragen kann.
 // Es koennen nur Attribute mit Ende abgefragt werden.
 // Es wird mit bDeep gesucht
-const SfxPoolItem* SwAttrIter::HasTextItem( USHORT nWhich ) const
+const SfxPoolItem* SwWW8AttrIter::HasTextItem( USHORT nWhich ) const
 {
     const SfxPoolItem* pRet = 0;
     const SwpHints* pTxtAttrs = rNd.GetpSwpHints();
@@ -631,7 +631,7 @@ void WW8Export::GetCurrentItems(WW8Bytes& rItems) const
         rItems.Insert((*pO)[nI], rItems.Count());
 }
 
-const SfxPoolItem& SwAttrIter::GetItem(USHORT nWhich) const
+const SfxPoolItem& SwWW8AttrIter::GetItem(USHORT nWhich) const
 {
     const SfxPoolItem* pRet = HasTextItem(nWhich);
     return pRet ? *pRet : rNd.SwCntntNode::GetAttr(nWhich);
@@ -665,7 +665,7 @@ void WW8AttributeOutput::StartRuby( const SwTxtNode& rNode, xub_StrLen /*nPos*/,
             cDirective = 'd';
             break;
         default:
-            ASSERT( !this,"Unhandled Ruby justication code" );
+            OSL_ENSURE( !this,"Unhandled Ruby justication code" );
             break;
     }
     aStr += String::CreateFromInt32( nJC );
@@ -764,7 +764,7 @@ String &TruncateBookmark( String &rRet )
 {
     if ( rRet.Len() > 40 )
         rRet.Erase( 40 );
-    ASSERT( rRet.Len() <= 40, "Word cannot have bookmarks longer than 40 chars" );
+    OSL_ENSURE( rRet.Len() <= 40, "Word cannot have bookmarks longer than 40 chars" );
     return rRet;
 }
 
@@ -796,7 +796,7 @@ bool AttributeOutputBase::AnalyzeURL( const String& rUrl, const String& /*rTarge
 
                 if ( bkmkName == sLink )
                 {
-                    sMark = String( RTL_CONSTASCII_STRINGPARAM( "_toc" ) );
+                    sMark = String( RTL_CONSTASCII_USTRINGPARAM( "_toc" ) );
                     sMark += String::CreateFromInt32( aIter->second );
                 }
             }
@@ -1019,7 +1019,7 @@ String BookmarkToWriter(const String &rBookmark)
         INetURLObject::DECODE_UNAMBIGUOUS, RTL_TEXTENCODING_ASCII_US);
 }
 
-void SwAttrIter::OutSwFmtRefMark(const SwFmtRefMark& rAttr, bool)
+void SwWW8AttrIter::OutSwFmtRefMark(const SwFmtRefMark& rAttr, bool)
 {
     if ( m_rExport.HasRefToObject( REF_SETREFATTR, &rAttr.GetRefName(), 0 ) )
         m_rExport.AppendBookmark( m_rExport.GetBookmarkName( REF_SETREFATTR,
@@ -1111,7 +1111,7 @@ void AttributeOutputBase::TOXMark( const SwTxtNode& rNode, const SwTOXMark& rAtt
             }
             break;
         default:
-            ASSERT( !this, "Unhandled option for toc export" );
+            OSL_ENSURE( !this, "Unhandled option for toc export" );
             break;
     }
 
@@ -1119,7 +1119,7 @@ void AttributeOutputBase::TOXMark( const SwTxtNode& rNode, const SwTOXMark& rAtt
         FieldVanish( sTxt, eType );
 }
 
-int SwAttrIter::OutAttrWithRange(xub_StrLen nPos)
+int SwWW8AttrIter::OutAttrWithRange(xub_StrLen nPos)
 {
     int nRet = 0;
     if ( const SwpHints* pTxtAttrs = rNd.GetpSwpHints() )
@@ -1180,7 +1180,7 @@ int SwAttrIter::OutAttrWithRange(xub_StrLen nPos)
     return nRet;
 }
 
-bool SwAttrIter::IsRedlineAtEnd( xub_StrLen nEnd ) const
+bool SwWW8AttrIter::IsRedlineAtEnd( xub_StrLen nEnd ) const
 {
     bool bRet = false;
     // search next Redline
@@ -1202,7 +1202,7 @@ bool SwAttrIter::IsRedlineAtEnd( xub_StrLen nEnd ) const
     return bRet;
 }
 
-const SwRedlineData* SwAttrIter::GetRedline( xub_StrLen nPos )
+const SwRedlineData* SwWW8AttrIter::GetRedline( xub_StrLen nPos )
 {
     if( pCurRedline )
     {
@@ -1327,7 +1327,7 @@ short MSWordExportBase::TrueFrameDirection( const SwFrmFmt &rFlyFmt ) const
     else
         nRet = GetCurrentPageDirection();
 
-    ASSERT( nRet != FRMDIR_ENVIRONMENT, "leaving with environment direction" );
+    OSL_ENSURE( nRet != FRMDIR_ENVIRONMENT, "leaving with environment direction" );
     return nRet;
 }
 
@@ -1397,7 +1397,7 @@ Convert characters that need to be converted, the basic replacements and the
 ridicously complicated title case attribute mapping to hardcoded upper case
 because word doesn't have the feature
 */
-String SwAttrIter::GetSnippet(const String &rStr, xub_StrLen nAktPos,
+String SwWW8AttrIter::GetSnippet(const String &rStr, xub_StrLen nAktPos,
     xub_StrLen nLen) const
 {
     String aSnippet(rStr, nAktPos, nLen);
@@ -1593,7 +1593,7 @@ void WW8AttributeOutput::FormatDrop( const SwTxtNode& rNode, const SwFmtDrop &rS
     m_rWW8Export.pO->Remove( 0, m_rWW8Export.pO->Count() );
 }
 
-xub_StrLen MSWordExportBase::GetNextPos( SwAttrIter* aAttrIter, const SwTxtNode& rNode, xub_StrLen nAktPos  )
+xub_StrLen MSWordExportBase::GetNextPos( SwWW8AttrIter* aAttrIter, const SwTxtNode& rNode, xub_StrLen nAktPos  )
 {
     // Get the bookmarks for the normal run
     xub_StrLen nNextPos = aAttrIter->WhereNext();
@@ -1601,17 +1601,18 @@ xub_StrLen MSWordExportBase::GetNextPos( SwAttrIter* aAttrIter, const SwTxtNode&
     GetSortedBookmarks( rNode, nAktPos, nNextPos - nAktPos );
 
     xub_StrLen nNextBookmark = nNextPos;
-    NearestBookmark( nNextPos );
+    NearestBookmark( nNextPos, nAktPos, false );
 
     return std::min( nNextPos, nNextBookmark );
 }
 
-void MSWordExportBase::UpdatePosition( SwAttrIter* aAttrIter, xub_StrLen nAktPos, xub_StrLen /*nEnd*/ )
+void MSWordExportBase::UpdatePosition( SwWW8AttrIter* aAttrIter, xub_StrLen nAktPos, xub_StrLen /*nEnd*/ )
 {
     xub_StrLen nNextPos;
 
-    // either no bookmark, or it is not at the current position
-    if ( !NearestBookmark( nNextPos ) || nNextPos > nAktPos )
+    // go to next attribute if no bookmark is found of if the bookmark is behind the next attribute position
+    bool bNextBookmark = NearestBookmark( nNextPos, nAktPos, true );
+    if( !bNextBookmark || nNextPos < aAttrIter->WhereNext() )
         aAttrIter->NextPos();
 }
 
@@ -1656,25 +1657,33 @@ public:
     }
 };
 
-bool MSWordExportBase::NearestBookmark( xub_StrLen& rNearest )
+bool MSWordExportBase::NearestBookmark( xub_StrLen& rNearest, const xub_StrLen nAktPos, bool bNextPositionOnly )
 {
     bool bHasBookmark = false;
 
     if ( m_rSortedMarksStart.size( ) > 0 )
     {
         IMark* pMarkStart = m_rSortedMarksStart.front();
-        rNearest = pMarkStart->GetMarkStart().nContent.GetIndex();
-        bHasBookmark = true;
+        xub_StrLen nNext = pMarkStart->GetMarkStart().nContent.GetIndex();
+        if( !bNextPositionOnly || (nNext > nAktPos ))
+        {
+            rNearest = nNext;
+            bHasBookmark = true;
+        }
     }
 
     if ( m_rSortedMarksEnd.size( ) > 0 )
     {
         IMark* pMarkEnd = m_rSortedMarksEnd[0];
-        if ( !bHasBookmark )
-            rNearest = pMarkEnd->GetMarkEnd().nContent.GetIndex();
-        else
-            rNearest = std::min( rNearest, pMarkEnd->GetMarkEnd().nContent.GetIndex() );
-        bHasBookmark = true;
+        xub_StrLen nNext = pMarkEnd->GetMarkEnd().nContent.GetIndex();
+        if( !bNextPositionOnly || nNext > nAktPos )
+        {
+            if ( !bHasBookmark )
+                rNearest = nNext;
+            else
+                rNearest = std::min( rNearest, nNext );
+            bHasBookmark = true;
+        }
     }
 
     return bHasBookmark;
@@ -1696,10 +1705,10 @@ void MSWordExportBase::GetSortedBookmarks( const SwTxtNode& rNode, xub_StrLen nA
             xub_StrLen nStart = pMark->GetMarkStart().nContent.GetIndex();
             xub_StrLen nEnd = pMark->GetMarkEnd().nContent.GetIndex();
 
-            if ( nStart > nAktPos )
+            if ( nStart > nAktPos && ( pMark->GetMarkStart().nNode == rNode.GetIndex()) )
                 aSortedStart.push_back( pMark );
 
-            if ( nEnd > nAktPos )
+            if ( nEnd > nAktPos && nEnd <= ( nAktPos + nLen ) && (pMark->GetMarkEnd().nNode == rNode.GetIndex()) )
                 aSortedEnd.push_back( pMark );
         }
 
@@ -1735,7 +1744,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
     // have to remember it in nStyle
     USHORT nStyle = nStyleBeforeFly;
 
-    SwAttrIter aAttrIter( *this, rNode );
+    SwWW8AttrIter aAttrIter( *this, rNode );
     rtl_TextEncoding eChrSet = aAttrIter.GetCharSet();
 
     if ( bStartTOX )
@@ -1767,13 +1776,13 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
 
     if ( aAttrIter.RequiresImplicitBookmark() )
     {
-        String sBkmkName = String( RTL_CONSTASCII_STRINGPARAM( "_toc" ) );
+        String sBkmkName = String( RTL_CONSTASCII_USTRINGPARAM( "_toc" ) );
         sBkmkName += String::CreateFromInt32( rNode.GetIndex() );
         AppendWordBookmark( sBkmkName );
     }
 
     //Would need to move into WW8Export, probably not worth it
-    //ASSERT( pO->Count(), " pO ist am Zeilenanfang nicht leer" );
+    // OSL_ENSURE( pO->Count(), " pO ist am Zeilenanfang nicht leer" );
 
     String aStr( rNode.GetTxt() );
 
@@ -1812,26 +1821,76 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
             IDocumentMarkAccess* const pMarkAccess = pDoc->getIDocumentMarkAccess();
             if ( ch == CH_TXT_ATR_FIELDSTART )
             {
-                SwPosition aPosition( rNode, SwIndex( const_cast< SwTxtNode* >( &rNode ), nAktPos + 1 ) );
+                SwPosition aPosition( rNode, SwIndex( const_cast< SwTxtNode* >( &rNode ), nAktPos ) );
                 ::sw::mark::IFieldmark const * const pFieldmark = pMarkAccess->getFieldmarkFor( aPosition );
                 OSL_ENSURE( pFieldmark, "Looks like this doc is broken...; where is the Fieldmark for the FIELDSTART??" );
 
                 if ( pFieldmark->GetFieldname().equalsAscii( ODF_FORMTEXT ) )
                     AppendBookmark( pFieldmark->GetName(), false );
-                OutputField( NULL, lcl_getFieldId( pFieldmark ), lcl_getFieldCode( pFieldmark ), WRITEFIELD_START | WRITEFIELD_CMD_START );
+                ww::eField eFieldId = lcl_getFieldId( pFieldmark );
+                String sCode = lcl_getFieldCode( pFieldmark );
+                if ( pFieldmark->GetFieldname().equalsAscii( ODF_UNHANDLED ) )
+                {
+                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find(
+                            rtl::OUString::createFromAscii( ODF_ID_PARAM ) );
+                    if ( it != pFieldmark->GetParameters()->end() )
+                    {
+                        rtl::OUString sFieldId;
+                        it->second >>= sFieldId;
+                        eFieldId = (ww::eField)sFieldId.toInt32();
+                    }
+
+                    it = pFieldmark->GetParameters()->find(
+                            rtl::OUString::createFromAscii( ODF_CODE_PARAM ) );
+                    if ( it != pFieldmark->GetParameters()->end() )
+                    {
+                        rtl::OUString sOUCode;
+                        it->second >>= sOUCode;
+                        sCode = sOUCode;
+                    }
+                }
+                OutputField( NULL, eFieldId, sCode, WRITEFIELD_START | WRITEFIELD_CMD_START );
                 if ( pFieldmark->GetFieldname( ).equalsAscii( ODF_FORMTEXT ) )
                     WriteFormData( *pFieldmark );
                 else if ( pFieldmark->GetFieldname( ).equalsAscii( ODF_HYPERLINK ) )
                     WriteHyperlinkData( *pFieldmark );
                 OutputField( NULL, lcl_getFieldId( pFieldmark ), String(), WRITEFIELD_CMD_END );
+
+                if ( pFieldmark->GetFieldname().equalsAscii( ODF_UNHANDLED ) )
+                {
+                    // Check for the presence of a linked OLE object
+                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find(
+                            rtl::OUString::createFromAscii( ODF_OLE_PARAM ) );
+                    if ( it != pFieldmark->GetParameters()->end() )
+                    {
+                        rtl::OUString sOleId;
+                        uno::Any aValue = it->second;
+                        aValue >>= sOleId;
+                        if ( sOleId.getLength( ) > 0 )
+                            OutputLinkedOLE( sOleId );
+                    }
+                }
             }
             else if ( ch == CH_TXT_ATR_FIELDEND )
             {
-                SwPosition aPosition( rNode, SwIndex( const_cast< SwTxtNode* >( &rNode ), nAktPos ) );
+                SwPosition aPosition( rNode, SwIndex( const_cast< SwTxtNode* >( &rNode ), nAktPos - 1 ) );
                 ::sw::mark::IFieldmark const * const pFieldmark = pMarkAccess->getFieldmarkFor( aPosition );
-                OSL_ENSURE( pFieldmark, "Looks like this doc is broken...; where is the Fieldmark for the FIELDSTART??" );
+                OSL_ENSURE( pFieldmark, "Looks like this doc is broken...; where is the Fieldmark for the FIELDEND??" );
 
-                OutputField( NULL, lcl_getFieldId( pFieldmark ), String(), WRITEFIELD_CLOSE );
+                ww::eField eFieldId = lcl_getFieldId( pFieldmark );
+                if ( pFieldmark->GetFieldname().equalsAscii( ODF_UNHANDLED ) )
+                {
+                    IFieldmark::parameter_map_t::const_iterator it = pFieldmark->GetParameters()->find(
+                            rtl::OUString::createFromAscii( ODF_ID_PARAM ) );
+                    if ( it != pFieldmark->GetParameters()->end() )
+                    {
+                        rtl::OUString sFieldId;
+                        it->second >>= sFieldId;
+                        eFieldId = (ww::eField)sFieldId.toInt32();
+                    }
+                }
+
+                OutputField( NULL, eFieldId, String(), WRITEFIELD_CLOSE );
                 if ( pFieldmark->GetFieldname().equalsAscii( ODF_FORMTEXT ) )
                     AppendBookmark( pFieldmark->GetName(), false );
             }
@@ -1874,7 +1933,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
         // Exception: footnotes at the end of line
         if ( nNextAttr == nEnd )
         {
-            ASSERT( nOpenAttrWithRange >= 0, "odd to see this happening, expected >= 0" );
+            OSL_ENSURE( nOpenAttrWithRange >= 0, "odd to see this happening, expected >= 0" );
             if ( !bTxtAtr && nOpenAttrWithRange <= 0 )
             {
                 if ( aAttrIter.IsRedlineAtEnd( nEnd ) )
@@ -1903,13 +1962,13 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
         // Exception: footnotes at the end of line
         if ( nNextAttr == nEnd )
         {
-            ASSERT(nOpenAttrWithRange >= 0,
+            OSL_ENSURE(nOpenAttrWithRange >= 0,
                 "odd to see this happening, expected >= 0");
             bool bAttrWithRange = (nOpenAttrWithRange > 0);
             if ( nAktPos != nEnd )
             {
                 nOpenAttrWithRange += aAttrIter.OutAttrWithRange(nEnd);
-                ASSERT(nOpenAttrWithRange == 0,
+                OSL_ENSURE(nOpenAttrWithRange == 0,
                     "odd to see this happening, expected 0");
             }
 
@@ -2248,7 +2307,7 @@ void MSWordExportBase::OutputTextNode( const SwTxtNode& rNode )
             pOutFmtNode = &rNode;
 
             // Pap-Attrs, so script is not necessary
-            OutputItemSet( *pNewSet, true, false, i18n::ScriptType::LATIN);
+            OutputItemSet( *pNewSet, true, false, i18n::ScriptType::LATIN, false);
 
             pStyAttr = 0;
             pOutFmtNode = pOldMod;
@@ -2296,108 +2355,6 @@ void WW8AttributeOutput::TableNodeInfo( ww8::WW8TableNodeInfo::Pointer_t pNodeIn
         aIt++;
     }
 }
-
-#if 0
-/*  */
-
-USHORT WW8Export::StartTableFromFrmFmt( WW8Bytes &rAt, const SwFrmFmt *pFmt )
-{
-    // Tell the undocumented table hack that everything between here and
-    // the last table position is nontable text
-    if ( WW8_CP nPos = Fc2Cp( Strm().Tell() ) )
-        pMagicTable->Append(nPos,0);
-
-    // sprmPDxaFromText10
-    if( bWrtWW8 )
-    {
-        static BYTE __READONLY_DATA  aTabLineAttr[] = {
-                0, 0,               // Sty # 0
-                0x16, 0x24, 1,      // sprmPFInTable
-                0x17, 0x24, 1 };    // sprmPFTtp
-        rAt.Insert( aTabLineAttr, sizeof( aTabLineAttr ), rAt.Count() );
-    }
-    else
-    {
-        static BYTE __READONLY_DATA  aTabLineAttr[] = {
-                0, 0,               // Sty # 0
-                24, 1,              // sprmPFInTable
-                25, 1 };            // sprmPFTtp
-        rAt.Insert( aTabLineAttr, sizeof( aTabLineAttr ), rAt.Count() );
-    }
-
-    ASSERT( pFmt, "No pFmt!" );
-    if ( pFmt )
-    {
-        const SwFmtHoriOrient &rHori = pFmt->GetHoriOrient();
-        const SwFmtVertOrient &rVert = pFmt->GetVertOrient();
-        if (
-            (text::RelOrientation::PRINT_AREA == rHori.GetRelationOrient() ||
-             text::RelOrientation::FRAME == rHori.GetRelationOrient())
-            &&
-            (text::RelOrientation::PRINT_AREA == rVert.GetRelationOrient() ||
-             text::RelOrientation::FRAME == rVert.GetRelationOrient())
-           )
-        {
-            sal_Int16 eHOri = rHori.GetHoriOrient();
-            switch (eHOri)
-            {
-                case text::HoriOrientation::CENTER:
-                case text::HoriOrientation::RIGHT:
-                    if( bWrtWW8 )
-                        SwWW8Writer::InsUInt16( rAt, NS_sprm::LN_TJc );
-                    else
-                        rAt.Insert( 182, rAt.Count() );
-                    SwWW8Writer::InsUInt16( rAt, (text::HoriOrientation::RIGHT == eHOri ? 2 : 1 ));
-                    break;
-                default:
-                    break;
-            }
-        }
-    }
-    return rAt.Count();
-}
-
-//See #i19484# for why we need this
-static bool CellContainsProblematicGraphic( const SwWriteTableCell *pCell,
-    const MSWordExportBase &rExport )
-{
-    const SwNode *pStart = pCell ? pCell->GetBox()->GetSttNd() : 0;
-    const SwNode *pEnd = pStart ? pStart->EndOfSectionNode() : 0;
-    ASSERT( pStart && pEnd, "No start or end?" );
-    if ( !pStart || !pEnd )
-        return false;
-
-    bool bHasGraphic = false;
-
-    sw::Frames aFrames( GetFramesBetweenNodes( rExport.maFrames, *pStart, *pEnd ) );
-    sw::FrameIter aEnd = aFrames.end();
-    for ( sw::FrameIter aIter = aFrames.begin(); aIter != aEnd; ++aIter )
-    {
-        const SwFrmFmt &rEntry = aIter->GetFrmFmt();
-        if ( rEntry.GetSurround().GetSurround() == SURROUND_THROUGHT )
-        {
-            bHasGraphic = true;
-            break;
-        }
-    }
-    return bHasGraphic;
-}
-
-static bool RowContainsProblematicGraphic( const SwWriteTableCellPtr *pRow,
-    USHORT nCols, const MSWordExportBase &rExport )
-{
-    bool bHasGraphic = false;
-    for ( USHORT nI = 0; nI < nCols; ++nI )
-    {
-        if ( CellContainsProblematicGraphic( pRow[nI], rExport ) )
-        {
-            bHasGraphic = true;
-            break;
-        }
-    }
-    return bHasGraphic;
-}
-#endif
 //---------------------------------------------------------------------------
 //       Tabellen
 //---------------------------------------------------------------------------
@@ -2507,7 +2464,7 @@ void WW8Export::AppendSection( const SwPageDesc *pPageDesc, const SwSectionFmt*
 
 void WW8Export::OutWW6FlyFrmsInCntnt( const SwTxtNode& rNd )
 {
-    ASSERT(!bWrtWW8, "I shouldn't be needed for Word >=8");
+    OSL_ENSURE(!bWrtWW8, "I shouldn't be needed for Word >=8");
     if ( bWrtWW8 )
         return;
 
@@ -2585,7 +2542,7 @@ void WW8AttributeOutput::OutputFlyFrame_Impl( const sw::Frame& rFmt, const Point
 
     if (bUseEscher)
     {
-        ASSERT( m_rWW8Export.bWrtWW8, "this has gone horribly wrong" );
+        OSL_ENSURE( m_rWW8Export.bWrtWW8, "this has gone horribly wrong" );
         // write as escher
         m_rWW8Export.AppendFlyInFlys(rFmt, rNdTopLeft);
     }
@@ -2739,7 +2696,7 @@ void WW8AttributeOutput::Redline( const SwRedlineData* pRedline )
         }
         break;
     default:
-        ASSERT(!this, "Unhandled redline type for export");
+        OSL_ENSURE(!this, "Unhandled redline type for export");
         break;
     }
 
@@ -2791,4 +2748,4 @@ void MSWordExportBase::OutputContentNode( const SwCntntNode& rNode )
     }
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
