@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,8 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-
 
 #include <iterator>
 #include <hintids.hxx>
@@ -69,7 +68,7 @@ wwZOrderer::wwZOrderer(const sw::util::SetLayer &rSetLayer, SdrPage* pDrawPg,
     mpShapeOrders(pShapeOrders)
 {
     mnNoInitialObjects = mpDrawPg->GetObjCount();
-    ASSERT(mpDrawPg,"Missing draw page impossible!");
+    OSL_ENSURE(mpDrawPg,"Missing draw page impossible!");
 }
 
 void wwZOrderer::InsideEscher(ULONG nSpId)
@@ -209,7 +208,7 @@ void wwZOrderer::InsertTextLayerObject(SdrObject* pObject)
             ++aIter;
         }
 
-        ASSERT(aEnd != maEscherLayer.end(), "Something very wrong here");
+        OSL_ENSURE(aEnd != maEscherLayer.end(), "Something very wrong here");
         if (aEnd != maEscherLayer.end())
         {
             aEnd->mnNoInlines++;
@@ -378,7 +377,7 @@ void SwWW8ImplReader::ReplaceObj(const SdrObject &rReplaceObj,
     }
     else
     {
-        ASSERT( !this, "Impossible!");
+        OSL_ENSURE( !this, "Impossible!");
     }
 }
 
@@ -633,8 +632,8 @@ SwFrmFmt* SwWW8ImplReader::ImportGraf(SdrTextObj* pTextObj,
                         pRecord->nDyTextBottom  );
 
                     MatchSdrItemsIntoFlySet( pObject, aAttrSet,
-                        pRecord->eLineStyle, pRecord->eShapeType,
-                        aInnerDist );
+                        pRecord->eLineStyle, pRecord->eLineDashing,
+                        pRecord->eShapeType, aInnerDist );
 
                     //Groesse aus der WinWord PIC-Struktur als
                     //Grafik-Groesse nehmen
@@ -821,4 +820,4 @@ void WW8FSPAShadowToReal( WW8_FSPA_SHADOW * pFSPAS, WW8_FSPA * pFSPA )
 }
 #endif // defined __WW8_NEEDS_COPY
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
