@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,8 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
-
 
 #include <svl/itemiter.hxx>
 #include <vcl/svapp.hxx>
@@ -142,13 +141,6 @@ eF_ResT SwWW8ImplReader::Read_F_FormTextBox( WW8FieldDesc* pF, String& rStr )
     if (!bUseEnhFields) {
     aFormula.sDefault = GetFieldResult(pF);
 
-#if 0 // why not? (flr)
-    //substituting Unicode spacing 0x2002 with double space for layout
-    aFormula.sDefault.SearchAndReplaceAll(
-        String(static_cast< sal_Unicode >(0x2002)),
-        CREATE_CONST_ASC("  "));
-#endif
-
     SwInputField aFld((SwInputFieldType*)rDoc.GetSysFldType( RES_INPUTFLD ),
               aFormula.sDefault , aFormula.sTitle , INP_TXT, 0 );
     aFld.SetHelp(aFormula.sHelp);
@@ -182,8 +174,8 @@ eF_ResT SwWW8ImplReader::Read_F_FormTextBox( WW8FieldDesc* pF, String& rStr )
     if (aBookmarkName.Len()>0) {
         maFieldStack.back().SetBookmarkName(aBookmarkName);
         maFieldStack.back().SetBookmarkType(::rtl::OUString::createFromAscii(ODF_FORMTEXT));
-        maFieldStack.back().getParameters()[::rtl::OUString::createFromAscii("Description")] = uno::makeAny(::rtl::OUString(aFormula.sToolTip));
-        maFieldStack.back().getParameters()[::rtl::OUString::createFromAscii("Name")] = uno::makeAny(::rtl::OUString(aFormula.sTitle));
+        maFieldStack.back().getParameters()[::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Description"))] = uno::makeAny(::rtl::OUString(aFormula.sToolTip));
+        maFieldStack.back().getParameters()[::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Name"))] = uno::makeAny(::rtl::OUString(aFormula.sTitle));
     }
     return FLD_TEXT;
     }
@@ -232,7 +224,7 @@ eF_ResT SwWW8ImplReader::Read_F_FormCheckBox( WW8FieldDesc* pF, String& rStr )
         IFieldmark* pFieldmark = dynamic_cast<IFieldmark*>( pMarksAccess->makeNoTextFieldBookmark(
                 *pPaM, aBookmarkName,
                 rtl::OUString::createFromAscii( ODF_FORMCHECKBOX ) ) );
-        ASSERT(pFieldmark!=NULL, "hmmm; why was the bookmark not created?");
+        OSL_ENSURE(pFieldmark!=NULL, "hmmm; why was the bookmark not created?");
         if (pFieldmark!=NULL) {
             IFieldmark::parameter_map_t* const pParameters = pFieldmark->GetParameters();
             ICheckboxFieldmark* pCheckboxFm = dynamic_cast<ICheckboxFieldmark*>(pFieldmark);
@@ -305,7 +297,7 @@ eF_ResT SwWW8ImplReader::Read_F_FormListBox( WW8FieldDesc* pF, String& rStr)
             IFieldmark *pFieldmark = dynamic_cast<IFieldmark*>(
                     pMarksAccess->makeNoTextFieldBookmark( *pPaM, aBookmarkName,
                            ::rtl::OUString::createFromAscii( ODF_FORMDROPDOWN ) ) );
-            ASSERT(pFieldmark!=NULL, "hmmm; why was the bookmark not created?");
+            OSL_ENSURE(pFieldmark!=NULL, "hmmm; why was the bookmark not created?");
             if ( pFieldmark != NULL )
             {
                 uno::Sequence< ::rtl::OUString > vListEntries(aFormula.maListEntries.size());
@@ -321,7 +313,7 @@ eF_ResT SwWW8ImplReader::Read_F_FormListBox( WW8FieldDesc* pF, String& rStr)
     }
 }
 
-eF_ResT SwWW8ImplReader::Read_F_HTMLControl( WW8FieldDesc* pF, String& rStr)
+eF_ResT SwWW8ImplReader::Read_F_HTMLControl(WW8FieldDesc*, String&)
 {
     if( bObj && nPicLocFc )
         nObjLocFc = nPicLocFc;
@@ -636,7 +628,7 @@ bool WW8ListManager::ReadLVL(SwNumFmt& rNumFmt, SfxItemSet*& rpItemSet,
                     }
                 }
             }
-            ASSERT(bDone, "tab setting in numbering is "
+            OSL_ENSURE(bDone, "tab setting in numbering is "
                 "of unexpected configuration");
         }
         if ( rNumFmt.GetPositionAndSpaceMode() ==
@@ -880,7 +872,7 @@ bool WW8ListManager::ReadLVL(SwNumFmt& rNumFmt, SfxItemSet*& rpItemSet,
             break;
          default:
             // undefied value
-            ASSERT( !this, "Value of aLVL.nAlign is not supported" );
+            OSL_ENSURE( !this, "Value of aLVL.nAlign is not supported" );
             // take default
             eAdj = SVX_ADJUST_LEFT;
             break;
@@ -1299,7 +1291,7 @@ WW8ListManager::WW8ListManager(SvStream& rSt_, SwWW8ImplReader& rReader_)
                 // 2.2.1 eine neue NumRule fuer diese Liste anlegen
                 //
                 SwNumRule* pParentNumRule = pLFOInfo->pNumRule;
-                ASSERT(pParentNumRule, "ww: Impossible lists, please report");
+                OSL_ENSURE(pParentNumRule, "ww: Impossible lists, please report");
                 if( !pParentNumRule )
                     break;
                 // Nauemsprefix aufbauen: fuer NumRule-Name (eventuell)
@@ -1408,7 +1400,9 @@ WW8ListManager::WW8ListManager(SvStream& rSt_, SwWW8ImplReader& rReader_)
                         pLFOInfo->pNumRule->Set(aLFOLVL.nLevel, aNumFmt);
                     }
                     bLVLOk = true;
-                    pLFOInfo->maOverrides[aLFOLVL.nLevel] = aLFOLVL;
+
+                    if (nMaxLevel > aLFOLVL.nLevel)
+                        pLFOInfo->maOverrides[aLFOLVL.nLevel] = aLFOLVL;
                 }
                 if( !bLVLOk )
                     break;
@@ -1575,7 +1569,7 @@ SwNumRule* WW8ListManager::GetNumRuleForActivation(sal_uInt16 nLFOPosition,
     if (pLFOInfo->bOverride && nLevel < pLFOInfo->nLfoLvl)
     {
         WW8LSTInfo* pParentListInfo = GetLSTByListId(pLFOInfo->nIdLst);
-        ASSERT(pParentListInfo, "ww: Impossible lists, please report");
+        OSL_ENSURE(pParentListInfo, "ww: Impossible lists, please report");
         if (pParentListInfo && pParentListInfo->pNumRule)
         {
             const WW8LFOLVL &rOverride = pLFOInfo->maOverrides[nLevel];
@@ -1639,7 +1633,7 @@ bool SwWW8ImplReader::SetTxtFmtCollAndListLevel(const SwPaM& rRg,
         bRes = rDoc.SetTxtFmtColl(rRg, (SwTxtFmtColl*)rStyleInfo.pFmt)
             ? true : false;
         SwTxtNode* pTxtNode = pPaM->GetNode()->GetTxtNode();
-        ASSERT( pTxtNode, "No Text-Node at PaM-Position" );
+        OSL_ENSURE( pTxtNode, "No Text-Node at PaM-Position" );
         // --> OD 2006-10-19 #134160# - make code robust
         if ( !pTxtNode )
         {
@@ -1726,7 +1720,7 @@ void SwWW8ImplReader::SetStylesList(sal_uInt16 nStyle, sal_uInt16 nActLFO,
     SwWW8StyInf &rStyleInf = pCollA[nStyle];
     if (rStyleInf.bValid)
     {
-        ASSERT(pAktColl, "Cannot be called outside of style import");
+        OSL_ENSURE(pAktColl, "Cannot be called outside of style import");
         // Phase 1: Nummerierungsattribute beim Einlesen einer StyleDef
         if( pAktColl )
         {
@@ -1809,7 +1803,7 @@ void SwWW8ImplReader::RegisterNumFmtOnTxtNode(sal_uInt16 nActLFO,
     {
         std::vector<sal_uInt8> aParaSprms;
         SwTxtNode* pTxtNd = pPaM->GetNode()->GetTxtNode();
-        ASSERT(pTxtNd, "Kein Text-Node an PaM-Position");
+        OSL_ENSURE(pTxtNd, "Kein Text-Node an PaM-Position");
 
         const SwNumRule* pRule = bSetAttr ?
             pLstManager->GetNumRuleForActivation( nActLFO, nActLevel,
@@ -1886,7 +1880,7 @@ void SwWW8ImplReader::RegisterNumFmtOnTxtNode(sal_uInt16 nActLFO,
                         RES_LR_SPACE);
                 const SvxLRSpaceItem *pItem = (const SvxLRSpaceItem*)(
                     GetFmtAttr(RES_LR_SPACE));
-                ASSERT(pItem, "impossible");
+                OSL_ENSURE(pItem, "impossible");
                 if (pItem)
                     aListIndent.Put(*pItem);
 
@@ -1913,7 +1907,7 @@ void SwWW8ImplReader::RegisterNumFmtOnTxtNode(sal_uInt16 nActLFO,
 
                 const SvxLRSpaceItem *pLR =
                     HasItem<SvxLRSpaceItem>(aListIndent, RES_LR_SPACE);
-                ASSERT(pLR, "Impossible");
+                OSL_ENSURE(pLR, "Impossible");
                 if (pLR)
                 {
                     pCtrlStck->NewAttr(*pPaM->GetPoint(), *pLR);
@@ -2232,7 +2226,7 @@ void WW8FormulaControl::FormulaRead(SwWw8ControlType nWhich,
                 nChecked = false;
                 break;
             default:
-                ASSERT(!this, "unknown option, please report to cmc");
+                OSL_ENSURE(!this, "unknown option, please report to cmc");
                 break;
         }
     }
@@ -2293,7 +2287,7 @@ void WW8FormulaControl::FormulaRead(SwWw8ControlType nWhich,
                 bAllOk = false;
             *pDataStream >> nNoStrings;
         }
-        ASSERT(bAllOk,
+        OSL_ENSURE(bAllOk,
             "Unknown formfield dropdown list structure. Report to cmc");
         if (!bAllOk)    //Not as expected, don't risk it at all.
             nNoStrings = 0;
@@ -2344,7 +2338,7 @@ awt::Size SwWW8ImplReader::MiserableDropDownFormHack(const String &rString,
     {
         bool bSet = true;
         const SfxPoolItem* pItem = GetFmtAttr( pMap->nWhichId );
-        ASSERT(pItem, "Impossible");
+        OSL_ENSURE(pItem, "Impossible");
         if (!pItem)
             continue;
 
@@ -2437,7 +2431,7 @@ awt::Size SwWW8ImplReader::MiserableDropDownFormHack(const String &rString,
     }
     // now calculate the size of the control
     OutputDevice* pOut = Application::GetDefaultDevice();
-    ASSERT(pOut, "Impossible");
+    OSL_ENSURE(pOut, "Impossible");
     if (pOut)
     {
         pOut->Push( PUSH_FONT | PUSH_MAPMODE );
@@ -2644,7 +2638,4 @@ sal_Bool SwMSConvertControls::InsertControl(
     return sal_True;
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
-
-
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
