@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -43,9 +44,7 @@
 #include "optcomp.hrc"
 #include "globals.hrc"
 #include <tools/urlobj.hxx>
-#ifndef _UTL__HXX_
 #include <unotools/configmgr.hxx>
-#endif
 #include <vcl/msgbox.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/docfilt.hxx>
@@ -182,15 +181,11 @@ SwCompatibilityOptPage::SwCompatibilityOptPage( Window* pParent, const SfxItemSe
     m_aOptionsLB.SetSizePixel( aNewSz );
 }
 
-// -----------------------------------------------------------------------
-
 SwCompatibilityOptPage::~SwCompatibilityOptPage()
 {
     delete m_pImpl;
 }
 
-// -----------------------------------------------------------------------
-
 void SwCompatibilityOptPage::ReplaceFormatName( String& rEntry )
 {
     static const String sOpenOfficeName = String::CreateFromAscii("OpenOffice.org");
@@ -216,8 +211,6 @@ void SwCompatibilityOptPage::ReplaceFormatName( String& rEntry )
     }
 }
 
-// -----------------------------------------------------------------------
-
 ULONG convertBools2Ulong_Impl
 (
     bool _bUsePrtMetrics,
@@ -272,8 +265,6 @@ ULONG convertBools2Ulong_Impl
     return nRet;
 }
 
-// -----------------------------------------------------------------------
-
 void SwCompatibilityOptPage::InitControls( const SfxItemSet& rSet )
 {
     // init objectshell and detect document name
@@ -406,8 +397,6 @@ void SwCompatibilityOptPage::InitControls( const SfxItemSet& rSet )
     }
 }
 
-// -----------------------------------------------------------------------
-
 IMPL_LINK( SwCompatibilityOptPage, SelectHdl, ListBox*, EMPTYARG )
 {
     USHORT nPos = m_aFormattingLB.GetSelectEntryPos();
@@ -417,8 +406,6 @@ IMPL_LINK( SwCompatibilityOptPage, SelectHdl, ListBox*, EMPTYARG )
     return 0;
 }
 
-// -----------------------------------------------------------------------
-
 IMPL_LINK( SwCompatibilityOptPage, UseAsDefaultHdl, PushButton*, EMPTYARG )
 {
     QueryBox aBox( this, WinBits( WB_YES_NO | WB_DEF_YES ), m_sUseAsDefaultQuery );
@@ -449,7 +436,7 @@ IMPL_LINK( SwCompatibilityOptPage, UseAsDefaultHdl, PushButton*, EMPTYARG )
                         case COPT_EXPAND_WORDSPACE:  pItem->m_bExpandWordSpace = bChecked; break;
                         default:
                         {
-                            DBG_ERRORFILE( "SwCompatibilityOptPage::UseAsDefaultHdl(): wrong option" );
+                            OSL_ENSURE(false, "SwCompatibilityOptPage::UseAsDefaultHdl(): wrong option" );
                         }
                     }
                 }
@@ -463,12 +450,10 @@ IMPL_LINK( SwCompatibilityOptPage, UseAsDefaultHdl, PushButton*, EMPTYARG )
     return 0;
 }
 
-// -----------------------------------------------------------------------
-
 void SwCompatibilityOptPage::SetCurrentOptions( ULONG nOptions )
 {
     ULONG nCount = m_aOptionsLB.GetEntryCount();
-    DBG_ASSERT( nCount <= 32, "SwCompatibilityOptPage::Reset(): entry overflow" );
+    OSL_ENSURE( nCount <= 32, "SwCompatibilityOptPage::Reset(): entry overflow" );
     for ( USHORT i = 0; i < nCount; ++i )
     {
         BOOL bChecked = ( ( nOptions & 0x00000001 ) == 0x00000001 );
@@ -477,8 +462,6 @@ void SwCompatibilityOptPage::SetCurrentOptions( ULONG nOptions )
     }
 }
 
-// -----------------------------------------------------------------------
-
 ULONG SwCompatibilityOptPage::GetDocumentOptions() const
 {
     ULONG nRet = 0;
@@ -501,8 +484,6 @@ ULONG SwCompatibilityOptPage::GetDocumentOptions() const
     return nRet;
 }
 
-// -----------------------------------------------------------------------
-
 void SwCompatibilityOptPage::WriteOptions()
 {
     m_aConfigItem.Clear();
@@ -517,15 +498,11 @@ void SwCompatibilityOptPage::WriteOptions()
             pItem->m_bExpandWordSpace );
 }
 
-// -----------------------------------------------------------------------
-
 SfxTabPage*	SwCompatibilityOptPage::Create( Window* pParent, const SfxItemSet& rAttrSet )
 {
     return new SwCompatibilityOptPage( pParent, rAttrSet );
 }
 
-// -----------------------------------------------------------------------
-
 BOOL SwCompatibilityOptPage::FillItemSet( SfxItemSet&  )
 {
     BOOL bModified = FALSE;
@@ -533,7 +510,7 @@ BOOL SwCompatibilityOptPage::FillItemSet( SfxItemSet&  )
     {
         ULONG nSavedOptions = m_nSavedOptions;
         ULONG nCount = m_aOptionsLB.GetEntryCount();
-        DBG_ASSERT( nCount <= 32, "SwCompatibilityOptPage::Reset(): entry overflow" );
+        OSL_ENSURE( nCount <= 32, "SwCompatibilityOptPage::Reset(): entry overflow" );
 
         bool bSetParaSpaceMax = false;
 
@@ -615,8 +592,6 @@ BOOL SwCompatibilityOptPage::FillItemSet( SfxItemSet&  )
     return bModified;
 }
 
-// -----------------------------------------------------------------------
-
 void SwCompatibilityOptPage::Reset( const SfxItemSet&  )
 {
     m_aOptionsLB.SelectEntryPos( 0 );
@@ -626,3 +601,4 @@ void SwCompatibilityOptPage::Reset( const SfxItemSet&  )
     m_nSavedOptions = nOptions;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
